@@ -11,6 +11,9 @@ from wagtail.core.utils import camelcase_to_underscore
 from modelcluster.fields import ParentalKey
 from wagtail.core.models import Orderable, Site
 
+from wagtailyoast.edit_handlers import YoastPanel
+from wagtail.admin.edit_handlers import TabbedInterface, ObjectList
+
 from webspace.bakery.models import VersionBuild
 from webspace.cms.amp.mixins import AmpMixin
 from webspace.cms.amp.utils import amp_mode_active
@@ -119,6 +122,8 @@ class AGenericPage(Page):
 
     amp_active = models.BooleanField(default=True)
 
+    keywords = models.CharField(default='', blank=True, max_length=100)
+
     body = StreamField([
         ('svg', SvgEntry()),
         ('image', ImageEntry()),
@@ -168,6 +173,18 @@ class AGenericPage(Page):
         InlinePanel("language_pages", label="Pages multi-language")
     ]
 
+    edit_handler = TabbedInterface([
+        ObjectList(content_panels, heading='Content'),
+        ObjectList(promote_panels, heading='Promotion'),
+        ObjectList(settings_panels, heading='Settings'),
+        YoastPanel(
+            keywords='keywords',
+            title='seo_title',
+            search_description='search_description',
+            slug='slug'
+        ),
+    ])
+
     subpage_types = [
         'cms.ContentPage',
         'cms.DocumentPage',
